@@ -20,10 +20,12 @@ PIN_MEMORY = True
 MAX_EPOCH = 50
 DEVICE = 'cuda' if torch.cuda.is_available() else 'cpu'
 CHECKPOINT_NAME = 'my_checkpoint'
+SMOOTH_FACTOR = 0.95
 
 
 def train_fn(loader, model, optimizer, loss_fn, scaler, device):
     loop = tqdm(loader)
+    smoothed_loss = None
 
     for batch_idx, (data, targets) in enumerate(loop):
         data = data.to(device=device)
@@ -41,7 +43,11 @@ def train_fn(loader, model, optimizer, loss_fn, scaler, device):
         scaler.update()
 
         # update tqdm loop
+        if smoothed_loss is None:
+            smoothed_loss = loss.item()
+        smoothed_loss = smoothed_loss*SMOOTH_FACTOR + loss.item()
         loop.set_postfix(loss=loss.item())
+        loop.set_postfix(smoothed=smoothed_loss)
 
 
 def loop_fn(model, optimizer, loss_fn, trainset, valset, batch_size, max_patience=10, checkpoint=None):
